def men_lol(the_list,indent=False,level=0):
	for mens in the_list:
		if isinstance(mens,list):
			men_lol(mens,indent,level+1)
		else:
			if indent:
				for tab_shop in range(level):
					print("\t",end='')
			print(mens)



from distutils.core import setup

setup(
       name          = 'menlol',
       version       = '1.0.4',
       py_modules    = ['menlol'],
       author        = 'holin',
       author_email  = 'holin@holin.net',
       url           = 'http://www.holin.net',
       description   = 'print a list',

        )

